Index: /issm/trunk/src/m/utils/Exp/expconcatenate.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/expconcatenate.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/expconcatenate.m	(revision 3018)
@@ -48,5 +48,5 @@
 
 %call merge profile routine
-[A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root);
+[A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root,options);
 
 hold off
Index: /issm/trunk/src/m/utils/Exp/expcut.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/expcut.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/expcut.m	(revision 3018)
@@ -48,5 +48,5 @@
 
 %call merge profile routine
-[A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root);
+[A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root,options);
 
 hold off
Index: /issm/trunk/src/m/utils/Exp/expselect.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/expselect.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/expselect.m	(revision 3018)
@@ -49,5 +49,5 @@
 
 %call merge profile routine
-[A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot,root);
+[A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 
 hold off
Index: /issm/trunk/src/m/utils/Exp/manipulation/addcontour.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/addcontour.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/addcontour.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=addcontour(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=addcontour(A,numprofiles,numpoints,closed,prevplot,root,options);
 %ADDCONTOUR - add a closed contour
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=addcontour(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=addcontour(A,numprofiles,numpoints,closed,prevplot,root,options)
 		   
 	title('click to add a point to the new profile, RETURN to exit','FontSize',14)
@@ -25,9 +25,7 @@
 			%plot everything
 			undoplots(prevplot);
-			if length(x)
-				plot(x,y,'-rs','MarkerSize',10);
-			end
-			plot(x,y,'rs','MarkerSize',10);
-			plot(x(end),y(end),'rs','MarkerSize',14);
+			plot(x,y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+				'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
+			plot(x(end),y(end),'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize')+2,'Marker',getfieldvalueerr(options,'Marker'));
 
 		else
Index: /issm/trunk/src/m/utils/Exp/manipulation/addendprofile.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/addendprofile.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/addendprofile.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=addendprofile(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=addendprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 %ADDENDPROFILE - add point at the end of a n existing profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=addendprofile(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=addendprofile(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	%some checks
@@ -48,13 +48,9 @@
 	%plot the selected profile
 	hold on
-	if length(x)
-		plot(x,y,'-rs','MarkerSize',10);
-	end
-	plot(x,y,'rs','MarkerSize',10);
-	plot(x(end),y(end),'rs','MarkerSize',14);
-
+	plot(x,y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+		'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
+	plot(x(end),y(end),'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize')+2,'Marker',getfieldvalueerr(options,'Marker'));
 
 	loop=1;
-
 	while loop
 
@@ -69,9 +65,7 @@
 			%plot everything
 			undoplots(prevplot);
-			if length(x)
-				plot(x,y,'-rs','MarkerSize',10);
-			end
-			plot(x,y,'rs','MarkerSize',10);
-			plot(x(end),y(end),'rs','MarkerSize',14);
+			plot(x,y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+				'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
+			plot(x(end),y(end),'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize')+2,'Marker',getfieldvalueerr(options,'Marker'));
 
 		else
Index: /issm/trunk/src/m/utils/Exp/manipulation/addinsideprofile.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/addinsideprofile.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/addinsideprofile.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=addinsideprofile(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=addinsideprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 %ADDINSIDEPROFILE - add apoint inside a profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=addinsideprofile(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=addinsideprofile(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	%some checks
@@ -18,11 +18,12 @@
 	end	   
 	hold on
-	loop=1;
 
 	%plot squares
 	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+		plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+			'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 	end
 
+	loop=1;
 	while loop
 
@@ -44,5 +45,7 @@
 
 			%highlight selected segment
-			plot([A(profsel).x(indsel) A(profsel).x(indsel+1)],[A(profsel).y(indsel) A(profsel).y(indsel+1)],'b-','MarkerSize',10);
+			plot([A(profsel).x(indsel) A(profsel).x(indsel+1)],[A(profsel).y(indsel) A(profsel).y(indsel+1)],...
+				'color',getfieldvalueerr(options,'selectioncolor'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+				'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 
 			%next click
@@ -61,5 +64,6 @@
 				undoplots(prevplot);
 				for i=1:numprofiles
-					plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+					plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+						'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 				end
 
Index: /issm/trunk/src/m/utils/Exp/manipulation/addprofile.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/addprofile.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/addprofile.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=addprofile(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=addprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 %ADDPROFILE - add a profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=addprofile(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=addprofile(A,numprofiles,numpoints,closed,prevplot,root,options)
 		   
 	title('click to add a point to the new profile, RETURN to exit','FontSize',14)
@@ -25,9 +25,7 @@
 			%plot everything
 			undoplots(prevplot);
-			if length(x)
-				plot(x,y,'-rs','MarkerSize',10);
-			end
-			plot(x,y,'rs','MarkerSize',10);
-			plot(x(end),y(end),'rs','MarkerSize',14);
+			plot(x,y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+				'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
+			plot(x(end),y(end),'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize')+2,'Marker',getfieldvalueerr(options,'Marker'));
 
 		else
Index: /issm/trunk/src/m/utils/Exp/manipulation/closeprofile.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/closeprofile.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/closeprofile.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=closeprofile(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=closeprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 %CLOSEPROFILE - close one or several profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=closeprofile(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=closeprofile(A,numprofiles,numpoints,closed,prevplot,root,options)
 
 	%some checks
@@ -42,6 +42,7 @@
 				%profile was in selection, remove it from the selection
 				selection(find(selection==profsel))=[];
-				%back to red
-				plot(A(profsel).x,A(profsel).y,'-r','MarkerSize',10);
+				%back to regular color
+				plot(A(profsel).x,A(profsel).y,...
+					'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 			elseif closed(profsel),
 				%profile already closed, do nothing
@@ -50,6 +51,7 @@
 				%add the profile to the list to be closed
 				selection(end+1)=profsel;
-				%in blue
-				plot(A(profsel).x,A(profsel).y,'-b','MarkerSize',10);
+				%in selectioncolor
+				plot(A(profsel).x,A(profsel).y,...
+					'color',getfieldvalueerr(options,'selectioncolor'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 			end
 		else
Index: /issm/trunk/src/m/utils/Exp/manipulation/cutarea.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/cutarea.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/cutarea.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root,options);
 %CUTAREA - cut several point of a profile
 %
@@ -9,5 +9,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	hold on
@@ -16,5 +16,6 @@
 	%plot squares
 	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+		plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+			'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 	end
 
@@ -55,5 +56,6 @@
 					selection=profsel;
 					points(end+1)=indsel;
-					plot(A(selection).x,A(selection).y,'-b','MarkerSize',10);
+					plot(A(profsel).x,A(profsel).y,...
+						'color',getfieldvalueerr(options,'selectioncolor'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 					text(A(selection).x(indsel),A(selection).y(indsel),num2str(1),'FontSize',14,'background',[0.7 0.7 0.9]);
 				end
@@ -135,5 +137,6 @@
 						undoplots(prevplot);
 						for i=1:numprofiles
-							plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+							plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+								'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 						end
 						points=[];
Index: /issm/trunk/src/m/utils/Exp/manipulation/cutprofile.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/cutprofile.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/cutprofile.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=cutprofile(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=cutprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 %CUTPROFILE - cut a profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=cutprofile(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=cutprofile(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	%some checks
@@ -18,11 +18,12 @@
 	end	   
 	hold on
-	loop=1;
 
 	%plot squares
 	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+		plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+			'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 	end
 
+	loop=1;
 	while loop
 
@@ -67,5 +68,6 @@
 				undoplots(prevplot);
 				for i=1:numprofiles
-					plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+					plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+						'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 				end
 			end
Index: /issm/trunk/src/m/utils/Exp/manipulation/mergeprofiles.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/mergeprofiles.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/mergeprofiles.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root,options);
 %MERGEPROFILES - merge profiles
 %
@@ -7,5 +7,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root,options)
 
 hold on
@@ -33,6 +33,7 @@
 end
 
-%plot the tips
-plot(tips(:,1),tips(:,2),'rs','Markersize',10);
+%plot the tips only
+plot(tips(:,1),tips(:,2),...
+	'LineStyle','none','MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 firsttip=1;
 
@@ -69,6 +70,8 @@
 
 			%plot selected tip
-			plot(tips(tip1,1),tips(tip1,2),'bs','MarkerSize',10);
-			plot(A(numprofile1).x,A(numprofile1).y,'-g');
+			plot(tips(tip1,1),tips(tip1,2),...
+				'LineStyle','none','MarkerEdgeColor',getfieldvalueerr(options,'selectioncolor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
+			plot(A(numprofile1).x,A(numprofile1).y,...
+				'color',getfieldvalueerr(options,'selectioncolor'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 
 		%second selection
@@ -133,8 +136,9 @@
 			undoplots(prevplot);
 			for i=1:numprofiles
-				plot(A(i).x,A(i).y,'-r','MarkerSize',10);
+				plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 			end
 			if ~isempty(tips)
-				plot(tips(:,1),tips(:,2),'rs','Markersize',10);
+				plot(tips(:,1),tips(:,2),...
+					'LineStyle','none','MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 			end
 
Index: /issm/trunk/src/m/utils/Exp/manipulation/modifyposition.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/modifyposition.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/modifyposition.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=modifyposition(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=modifyposition(A,numprofiles,numpoints,closed,prevplot,root,options);
 %MODIFYPOSITION - modify the prosition of a point of a profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=modifyposition(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=modifyposition(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	%some checks
@@ -19,5 +19,6 @@
 	%plot squares
 	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+		plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+			'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 	end
 
@@ -34,5 +35,7 @@
 
 			%plot the point in blue
-			plot(A(profsel).x(indsel),A(profsel).y(indsel),'bs','MarkerSize',10);
+			plot(A(profsel).x(indsel),A(profsel).y(indsel),...
+				'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+				'MarkerEdgeColor',getfieldvalueerr(options,'selectioncolor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 
 			%select new location
@@ -60,5 +63,6 @@
 				undoplots(prevplot);
 				for i=1:numprofiles
-					plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+					plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+						'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 				end
 			else
Index: /issm/trunk/src/m/utils/Exp/manipulation/removepoints.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/removepoints.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/removepoints.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=removepoints(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=removepoints(A,numprofiles,numpoints,closed,prevplot,root,options);
 %REMOVEPOINTS - remove a point from a profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=removepoints(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=removepoints(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	%some checks
@@ -19,5 +19,6 @@
 	%plot squares
 	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+		plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+			'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 	end
 
@@ -68,5 +69,6 @@
 			undoplots(prevplot);
 			for i=1:numprofiles
-				plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+				plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+					'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 			end
 
Index: /issm/trunk/src/m/utils/Exp/manipulation/removeprofile.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/removeprofile.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/removeprofile.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 %REMOVEPROFILE - delete a profile
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot,root,options)
 
 	title('click on the profiles to be removed, RETURN to exit','FontSize',14)
@@ -32,11 +32,13 @@
 				%profile was in selection, remove it
 				selection(find(selection==profsel))=[];
-				%back to red
-				plot(A(profsel).x,A(profsel).y,'-r','MarkerSize',10);
+				%back to regular color
+				plot(A(profsel).x,A(profsel).y,...
+					'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 			else
 				%add the profile to the list to be removed
 				selection(end+1)=profsel;
-				%in blue
-				plot(A(profsel).x,A(profsel).y,'-b','MarkerSize',10);
+				%in selectioncolor
+				plot(A(profsel).x,A(profsel).y,...
+					'color',getfieldvalueerr(options,'selectioncolor'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 			end
 		else
Index: /issm/trunk/src/m/utils/Exp/manipulation/removeseveralpoints.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/manipulation/removeseveralpoints.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/manipulation/removeseveralpoints.m	(revision 3018)
@@ -1,3 +1,3 @@
-function [A,numprofiles,numpoints,closed]=removeseveralpoints(A,numprofiles,numpoints,closed,prevplot,root);
+function [A,numprofiles,numpoints,closed]=removeseveralpoints(A,numprofiles,numpoints,closed,prevplot,root,options);
 %REMOVESEVERALPOINTS - remove several point
 %
@@ -6,5 +6,5 @@
 %
 %   Usage:
-%      [A,numprofiles,numpoints,closed]=removeseveralpoints(A,numprofiles,numpoints,closed,prevplot,root)
+%      [A,numprofiles,numpoints,closed]=removeseveralpoints(A,numprofiles,numpoints,closed,prevplot,root,options)
 		
 	%some checks
@@ -22,5 +22,6 @@
 	%plot squares
 	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+		plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+			'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 	end
 
@@ -57,5 +58,6 @@
 					selection=profsel;
 					points(end+1)=indsel;
-					plot(A(selection).x,A(selection).y,'-b','MarkerSize',10);
+					plot(A(profsel).x,A(profsel).y,...
+						'color',getfieldvalueerr(options,'selectioncolor'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
 					text(A(selection).x(indsel),A(selection).y(indsel),num2str(1),'FontSize',14,'background',[0.7 0.7 0.9]);
 				end
@@ -113,5 +115,6 @@
 						undoplots(prevplot);
 						for i=1:numprofiles
-							plot(A(i).x,A(i).y,'-rs','MarkerSize',10);
+							plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'),...
+								'MarkerEdgeColor',getfieldvalueerr(options,'MarkerEdgeColor'),'MarkerSize',getfieldvalueerr(options,'MarkerSize'),'Marker',getfieldvalueerr(options,'Marker'));
 						end
 						points=[];

Index: /issm/trunk/src/m/utils/Exp/expmaster.m
===================================================================
--- /issm/trunk/src/m/utils/Exp/expmaster.m	(revision 3017)
+++ /issm/trunk/src/m/utils/Exp/expmaster.m	(revision 3018)
@@ -4,15 +4,22 @@
 %   this routine is used to create, modify, cut,... an Argus file (.exp)
 %
-%   expmaster(newprofile)
+%   expmaster(newprofile,'optionname',optionvalue)
 %      creation of an argus file newprofile
 %
-%   expmaster(newprofile,oldprofile)
-%      the modification of the file oldprofile will be saved in newprofile
-%
-%   expmaster(newprofile,oldprofile1,oldprofile2,...)
-%      the modification of the files oldprofile* will be saved in newprofile
+%   Available options:
+%      - include: include list of existing ARGUS files
+%      - color: line color (default='r')
+%      - selectioncolor: line color of selected profiles (default='b')
+%      - linestyle (default='-')
+%      - linewidth (default=1)
+%      - marker (default='s')
+%      - markersize (default=10)
+%      - markeredgecolor (default='r')
 %
 %   Usage:
 %      expmaster(newfile,varargin)
+%
+%   Example:
+%      expmaster('domain.exp','include',{'domain1.exp' 'domain2.exp'},'color','g','marker','+')
 %
 %   See also EXPDOC
@@ -21,8 +28,8 @@
 if ~nargin | nargout
 	error('expmaster usage: expmaster(newfile,varargin)')
-elseif exist(newfile),
+elseif exist(newfile,'file'),
 	%recursive call to expmaster if file already exists
 	if nargin==1,
-		expmaster(newfile,newfile);
+		expmaster(newfile,'include',newfile,varargin{:});
 		return;
 	end
@@ -36,4 +43,16 @@
 end
 
+%recover options
+options=pairoptions(varargin{:});
+
+%Add default options
+options=addfielddefault(options,'color','r');
+options=addfielddefault(options,'selectioncolor','b');
+options=addfielddefault(options,'LineStyle','-');
+options=addfielddefault(options,'LineWidth',1);
+options=addfielddefault(options,'Marker','s');
+options=addfielddefault(options,'MarkerSize',10);
+options=addfielddefault(options,'MarkerEdgeColor','r');
+
 %put all the argus profiles given in input in one structure A
 A=struct([]);
@@ -41,27 +60,33 @@
 numpoints=0;
 closed=[];
-for i=1:nargin-1
-	filename=varargin{i};
-	if ~exist(filename),
-		error(['expmaster error message:, ' filename ' does not exist. Exiting...']);
-	else
-		%read file
-		B=expread(filename,1);
-		%go through all profiles of B
-		for i=1:size(B,2)
-			%plug profile in A
-			if numprofiles
-				A(numprofiles+1)=B(i);
-			else
-				A=B(i);
-			end
-			%update numprofiles and numpoints
-			numpoints=numpoints+length(B(i).x);
-			numprofiles=numprofiles+1;
-			%figure out if the profile is closed or not
-			if (B(i).x(1)==B(i).x(end) & B(i).y(1)==B(i).y(end))
-				closed(numprofiles)=1;
-			else
-				closed(numprofiles)=0;
+
+%initialize the variables with files provided by 'include' option
+if exist(options,'include'),
+	files=getfieldvalueerr(options,'include');
+	if ischar(files), files={files}; end
+	for i=1:length(files),
+		filename=files{i};
+		if ~exist(filename,'file'),
+			error(['expmaster error message:, ' filename ' does not exist. Exiting...']);
+		else
+			%read file
+			B=expread(filename,1);
+			%go through all profiles of B
+			for i=1:size(B,2)
+				%plug profile in A
+				if numprofiles
+					A(numprofiles+1)=B(i);
+				else
+					A=B(i);
+				end
+				%update numprofiles and numpoints
+				numpoints=numpoints+length(B(i).x);
+				numprofiles=numprofiles+1;
+				%figure out if the profile is closed or not
+				if (B(i).x(1)==B(i).x(end) & B(i).y(1)==B(i).y(end))
+					closed(numprofiles)=1;
+				else
+					closed(numprofiles)=0;
+				end
 			end
 		end
@@ -96,11 +121,5 @@
 
 %plot existing profile if any
-
 hold on
-if numprofiles
-	for i=1:numprofiles
-		plot(A(i).x,A(i).y,'-r','MarkerSize',10);
-	end
-end
 
 %Build backup structre for do and redo
@@ -125,4 +144,14 @@
 	A(list)=[];
 	closed(list)=[];
+
+	%Now erase all that have been done and plot the new structure A as it is
+	undoplots(prevplot);
+	if numprofiles
+		prevplot2=1;
+		for i=1:numprofiles
+			plot(A(i).x,A(i).y,'color',getfieldvalueerr(options,'color'),'LineStyle',getfieldvalueerr(options,'LineStyle'),'LineWidth',getfieldvalueerr(options,'LineWidth'));
+			prevplot2=prevplot2+1;
+		end
+	end
 
 	%display menu
@@ -175,5 +204,5 @@
 		case 1
 
-			[A,numprofiles,numpoints,closed]=addprofile(A,numprofiles,numpoints,closed,prevplot2,root);
+			[A,numprofiles,numpoints,closed]=addprofile(A,numprofiles,numpoints,closed,prevplot2,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -184,5 +213,5 @@
 		case 2
 
-			[A,numprofiles,numpoints,closed]=addcontour(A,numprofiles,numpoints,closed,prevplot2,root);
+			[A,numprofiles,numpoints,closed]=addcontour(A,numprofiles,numpoints,closed,prevplot2,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -193,5 +222,5 @@
 		case 3
 
-			[A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot2,root);
+			[A,numprofiles,numpoints,closed]=removeprofile(A,numprofiles,numpoints,closed,prevplot2,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -202,5 +231,5 @@
 		case 4
 
-			[A,numprofiles,numpoints,closed]=modifyposition(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=modifyposition(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -211,5 +240,5 @@
 		case 5
 
-			[A,numprofiles,numpoints,closed]=addinsideprofile(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=addinsideprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -220,5 +249,5 @@
 		case 6
 
-			[A,numprofiles,numpoints,closed]=addendprofile(A,numprofiles,numpoints,closed,prevplot2,root);
+			[A,numprofiles,numpoints,closed]=addendprofile(A,numprofiles,numpoints,closed,prevplot2,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -229,5 +258,5 @@
 		case 7
 
-			[A,numprofiles,numpoints,closed]=removepoints(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=removepoints(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -238,5 +267,5 @@
 		case 8
 
-			[A,numprofiles,numpoints,closed]=removeseveralpoints(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=removeseveralpoints(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -247,5 +276,5 @@
 		case 9
 
-			[A,numprofiles,numpoints,closed]=cutprofile(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=cutprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -256,5 +285,5 @@
 		case 10
 
-			[A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=cutarea(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -265,5 +294,5 @@
 		case 11
 
-			[A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=mergeprofiles(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -275,5 +304,5 @@
 		case 12
 
-			[A,numprofiles,numpoints,closed]=closeprofile(A,numprofiles,numpoints,closed,prevplot,root);
+			[A,numprofiles,numpoints,closed]=closeprofile(A,numprofiles,numpoints,closed,prevplot,root,options);
 			counter=counter+1;
 			backup{counter,1}=A;
@@ -293,13 +322,4 @@
 	end
 
-	%Now erase all that have been done and plot the new structure A as it is
-	undoplots(prevplot);
-	if numprofiles
-		prevplot2=1;
-		for i=1:numprofiles
-			plot(A(i).x,A(i).y,'-r','MarkerSize',10);
-			prevplot2=prevplot2+1;
-		end
-	end
 end
 